import argparse
import urllib.request
import time


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('--scheme', required=True, choices=['http', 'https'])
    parser.add_argument('--host', required=True)
    parser.add_argument('--port', required=True)
    parser.add_argument('--basepath', required=True)
    parser.add_argument('--client-name', required=True)
    parser.add_argument('--token', required=True)
    parser.add_argument('--cycle', required=True)
    args = parser.parse_args()
    scheme = args.scheme
    host = args.host
    port = args.port
    basepath = args.basepath
    client_name = args.client_name
    token = args.token
    cycle = args.cycle
    url = '%s://%s:%s/%s/updateClient.action?clientid=%s&token=%s' % (scheme, host, port, basepath, client_name, token)
    while True:
        with urllib.request.urlopen(url) as f:
            res = f.read()
        time.sleep(cycle)


if __name__ == '__main__':
    main()


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="heartbeat-client",
    version="0.2.0",
    author="Hawthorn2013",
    author_email="hawthorn7dd@hotmail.com",
    description="Heartbeat client implements with python.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Hawthorn2013/heartbeat-client-python",
    packages=setuptools.find_packages(),
    entry_points={
        'console_scripts': ['heartbeat=heartbeat_client.main:main'],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)